@@ -4,7 +4,7 @@ use warnings;
 
 package Mxpress::PDF {
 	BEGIN {
-		our $VERSION = '0.25';
+		our $VERSION = '0.26';
 		our $AUTHORITY = 'cpan:LNATION';
 	};
 	use Zydeco;
@@ -435,7 +435,7 @@ package Mxpress::PDF {
 			has end (is => 'rw', type => Num);
 			method generic_new (Object $file, Map %args) {
 				return $class->new(
-					padding => $args{padding} || 0,
+					padding => $args{padding} || 0,	
 					%args,
 					file => $file,
 					fill_colour => $file->page->valid_colour($args{fill_colour} || '#fff'),
@@ -449,7 +449,12 @@ package Mxpress::PDF {
 			}
 			class +Line {
 				has end_position (is => 'rw');
+				has type (is => 'rw', type => Str);
+				has dash (is => 'rw', type => ArrayRef);
+				has join (is => 'rw', type => Num);
 				factory line (Object $file, Map %args) {
+					$args{line_join} ||= 2;
+					$args{line_type} ||= 'solid';
 					$class->generic_new($file, %args);
 				}
 				method shape (Object $shape) {
@@ -457,6 +462,14 @@ package Mxpress::PDF {
 					my ($x, $y, $w, $h) = $self->parse_position($self->position || []);
 					$shape->move($x, $y);
 					($x, $y) = $self->end_position ? $self->parse_position($self->end_position) : ($x + $w, $y);
+					if ($self->dash) {
+						$shape->linedash(@{$self->dash});
+					} elsif ($self->type eq 'dots') {
+						$shape->linedash(1, 1);
+					} elsif ($self->type eq 'dashed') {
+						$shape->linedash(5, 5);
+					}				
+					$shape->linejoin($self->join);
 					$shape->line($x, $y);
 					$shape->stroke;
 				}
@@ -1302,7 +1315,7 @@ Mxpress::PDF - PDF
 
 =head1 VERSION
 
-Version 0.25
+Version 0.26
 
 =cut
 
@@ -1403,7 +1416,7 @@ This is experimental and may yet still change.
 	$pdf->text->add('italic text,', font => $italic, concat => \1);
 	$pdf->text->add('default text.', font => $default, concat => \1);
 
-	$pdf->border->start;
+	$pdf->border->start(type => 'dots');
 	for (0 .. 100) {
 		$pdf->toc->add(
 			[qw/title subtitle subsubtitle/]->[int(rand(3))] => $gen_text->(4)
@@ -2358,6 +2371,59 @@ The position of the line
 
 	$line->end_position([$x, $y]);
 
+=head3 type (is => 'rw', type => Str);
+
+Sets the type of line style.
+
+=over 
+
+=item solid
+
+The default which is a solid line.
+
+=item dots
+
+A line built out of dots, equivelant to setting dash as:
+
+	[1, 1]
+
+=item dashed
+
+A line built out of dashes, equivelant to setting dash as:
+
+	[5, 5]
+
+=back
+
+=head3 dash (is => 'rw', type => ArrayRef);
+
+The arguments represent alternating dash and gap lengths. 
+
+	[10, 10]
+
+=head3 join (is => 'rw', type => Num);
+
+Sets the style of join to be used at corners of a path.
+ 
+=over
+ 
+=item 0 = Miter Join
+ 
+The outer edges of the stroke extend until they meet, up to the limit
+specified below.  If the limit would be surpassed, a bevel join is
+used instead.
+ 
+=item 1 = Round Join
+ 
+A circle with a diameter equal to the linewidth is drawn around the
+corner point, producing a rounded corner.
+ 
+=item 2 = Bevel Join
+ 
+A triangle is drawn to fill in the notch between the two strokes.
+ 
+=back
+
 =head2 Methods
 
 The following methods can be called from a Mxpress::PDF::Plugin::Shape::Line Object.
